#!/bin/bash

VIEWERNAME="Alchemy" #Store the viewer's name as a variable, for portability. This should be correctly capitalized.

SCRIPTSRC="$(readlink -f "$0" || echo "$0")"
RUN_PATH="$(dirname "${SCRIPTSRC}" || echo .)"

install_prefix=$(builtin cd "${RUN_PATH}/.." || exit; pwd) #This is a cleaner way of getting the absolute path for the install directory.

function install_desktop_entry()
{
	local installation_prefix="${1}"

	desktoppath="${installation_prefix}/${VIEWERNAME,,}-viewer.desktop"
	cat >"${desktoppath}" <<desktopfile || print "Warning: Could not write $desktoppath"s
[Desktop Entry]
Version=1.4
Name=${VIEWERNAME}
GenericName=Second Life Viewer
Comment=Client for the Online Virtual World, Second Life
Exec=${installation_prefix}/${VIEWERNAME,,}
Icon=${VIEWERNAME}-Viewer
Terminal=false
Type=Application
Categories=Game;Simulation;
StartupNotify=true
StartupWMClass=${VIEWERNAME}
PrefersNonDefaultGPU=true
Actions=DefaultGPU;AssociateMIME;

[Desktop Action DefaultGPU]
Exec=${installation_prefix}/${VIEWERNAME,,}
Name=Launch on default GPU
Comment=Launch the viewer using the system's integrated GPU, instead of the dedicated one. (if available)
PrefersNonDefaultGPU=false

[Desktop Action AssociateMIME]
Exec=.${installation_prefix}/etc/register_secondlifeprotocol.sh
Name=Associate SLURLs
Comment=Set this viewer as the default handler for secondlife:// links.
Terminal=true
desktopfile

#The "PrefersNonDefaultGPU" line should automatically run the viewer on the most powerful GPU in the system, if it is not default. If it is, this is ignored.

# NOTE: DO NOT CHANGE THE "GenericName" FIELD - ONLY CHANGE THE "Name" FIELD. (This is to ensure that searching "Second Life" will show all the viewers installed in a user's system, regardless of their canonical name.)

	echo " - Installing menu entries via XDG..."
	xdg-icon-resource install --novendor --size 256 "${install_prefix}/${VIEWERNAME,,}_icon.png" ${VIEWERNAME}-Viewer
	#NOTE: Above command takes the path to the icon to install && The name of the icon to be used by XDG. This should always be in the format of "x-Viewer" to avoid potential naming conflicts, as per XDG spec.
	xdg-desktop-menu install --novendor ./${VIEWERNAME,,}-viewer.desktop
}

if [ "$UID" == "0" ]; then
	# system-wide
	install_desktop_entry "${install_prefix}" /usr/local/share/applications
else
	# user-specific
	install_desktop_entry "${install_prefix}" "${HOME}/.local/share/applications"
fi
